@@ -3,7 +3,7 @@ use std::path::Path;
 use std::time::SystemTime;
 
 use semver::Version;
-use serde::{Deserialize, Serialize};
+use serde_derive::{Deserialize, Serialize};
 
 use crate::error::*;
 
