@@ -1,7 +1,7 @@
 #[macro_export]
 macro_rules! bat_warning {
     ($($arg:tt)*) => ({
-        use ansi_term::Colour::Yellow;
+        use nu_ansi_term::Color::Yellow;
         eprintln!("{}: {}", Yellow.paint("[bat warning]"), format!($($arg)*));
     })
 }
